#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXPM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXPM_HPP_INCLUDED

#include <nt2/linalg/include/functions/scalar/expm.hpp>

#endif
